@@ -168,6 +168,20 @@ class CommandTestCase(unittest.TestCase):
             PgxnClientException, c.popen, "this-script-doesnt-exist"
         )
 
+    @patch('sys.stdout')
+    def test_empty_command(self, stdout):
+        from pgxnclient.cli import main
+
+        stdout.encoding = None
+        main([])
+        out = get_stdout_data(stdout)
+
+        # The output is the same of 'help'
+        stdout.reset_mock()
+        main(["help"])
+        out_help = get_stdout_data(stdout)
+        assert out == out_help
+
 
 class DownloadTestCase(unittest.TestCase):
     @patch('pgxnclient.network.get_file')
@@ -599,7 +613,7 @@ class InstallTestCase(unittest.TestCase, Assertions):
         make_cwd = self.mock_popen.call_args_list[1][1]['cwd']
 
         self.assertEquals(mock_unpack.call_count, 1)
-        tmpdir, = mock_unpack.call_args[0]
+        (tmpdir,) = mock_unpack.call_args[0]
         self.assertEqual(make_cwd, os.path.join(tmpdir, 'foobar-0.42.1'))
 
     @patch('pgxnclient.zip.ZipArchive.unpack')
@@ -621,7 +635,7 @@ class InstallTestCase(unittest.TestCase, Assertions):
         make_cwd = self.mock_popen.call_args_list[1][1]['cwd']
 
         self.assertEquals(mock_unpack.call_count, 1)
-        tmpdir, = mock_unpack.call_args[0]
+        (tmpdir,) = mock_unpack.call_args[0]
         self.assertEqual(make_cwd, os.path.join(tmpdir, 'foobar-0.42.1'))
 
     def test_install_url_file(self):
@@ -798,6 +812,9 @@ class LoadTestCase(unittest.TestCase):
         cmd = Load(None)
         self.assertEquals((9, 0, 3), cmd.parse_pg_version('90003'))
         self.assertEquals((9, 1, 0), cmd.parse_pg_version('90100'))
+        self.assertEquals((10, 0), cmd.parse_pg_version('100000'))
+        self.assertEquals((13, 2), cmd.parse_pg_version('130002'))
+        self.assertEquals((13, 2), cmd.parse_pg_version('130002\n'))
 
     @patch('pgxnclient.network.get_file')
     def test_check_psql_options(self, mock_get):
@@ -807,6 +824,7 @@ class LoadTestCase(unittest.TestCase):
 
         main(['load', '--yes', '--dbname', 'dbdb', 'foobar'])
         args = self.mock_popen.call_args[0][0]
+        assert "-tAX" in args
         self.assertEqual('dbdb', args[args.index('--dbname') + 1])
 
         main(['load', '--yes', '-U', 'meme', 'foobar'])
@@ -1161,7 +1179,10 @@ def get_stdout_data(mock):
     # TODO: reorganize tests to be less verbose and do this kind of cruft
     # with fixtures and pytest-foo
     calls = mock.write.call_args_list or mock.buffer.write.call_args_list
-    return b''.join([a[0] for a, k in calls])
+    out = [a[0] for a, k in calls]
+    if out and not isinstance(out[0], bytes):
+        out = [x.encode("utf-8", "replace") for x in out]  # just guessing
+    return b''.join(out)
 
 
 if __name__ == '__main__':
